@@ -18,12 +18,7 @@ from pkg_resources import DistributionNotFound, get_distribution
 
 from .checks import checks_exist, perform_checks
 from .log_parsing import show_log_advice
-from .testing import (
-    do_options_parsing,
-    enter_debugging,
-    prepare_reproduce,
-    prepare_test,
-)
+from .testing import enter_debugging, prepare_reproduce, prepare_test
 from .utils import (
     available_productions,
     check_production,
@@ -204,6 +199,7 @@ def validate(production_name):
 @main.command()
 @click.argument("production_name", type=production_name_type, nargs=1)
 @click.argument("job_name", type=str, nargs=1)
+@click.option("--validate/--no-validate", default=True)
 @click.option(
     "-i",
     "--dependent-input",
@@ -211,28 +207,27 @@ def validate(production_name):
     nargs=1,
     help="Run the test on a specific input file by passing either an LFN or a path to a local file",
 )
-def test(production_name, job_name, dependent_input):
+def test(production_name, job_name, dependent_input, validate):
     """Execute a job locally"""
-
-    validate_environment()
+    if validate:
+        validate_environment()
     inside_ap_datapkg()
 
-    out_dir, env_cmd, gaudi_cmd = prepare_test(
+    out_dir, prodrun_config_path = prepare_test(
         production_name, job_name, dependent_input
     )
 
-    cmd = env_cmd + gaudi_cmd
-    click.secho(f"Starting lb-run with: {shlex.join(cmd)}", fg="green")
+    cmd = ["lb-prod-run", prodrun_config_path, "--verbose"]
+    click.secho(f"Starting application with: {shlex.join(cmd)}", fg="green")
     result = logging_subprocess_run(cmd, cwd=out_dir)
 
-    with open(join(out_dir, "stdout.log"), "wb") as fp:
-        fp.write(result.stdout)
-
-    with open(join(out_dir, "stderr.log"), "wb") as fp:
-        fp.write(result.stderr)
+    (out_dir / "stdout.log").write_bytes(result.stdout)
+    (out_dir / "stderr.log").write_bytes(result.stderr)
 
     click.secho("Summary of log messages:", fg="green")
-    show_log_advice(result.stdout.decode() + "\n" + result.stderr.decode())
+    show_log_advice(
+        b"\n".join([result.stdout, result.stderr]).decode(errors="backslashreplace")
+    )
 
     if result.returncode != 0:
         raise click.ClickException("Execution failed, see above for details")
@@ -248,41 +243,43 @@ def test(production_name, job_name, dependent_input):
         raise click.ClickException(
             f"Job {job_name} is not found for production {production_name}!"
         )
-    output_file = job_data["output"].pop()
+    output_file = job_data["output"][0]
 
     # Validating Gaudi options
-    test_ntuple_path = join(out_dir, f"00012345_00006789_1.{output_file}")
+    test_ntuple_path = out_dir / f"00012345_00006789_1.{output_file}"
 
     errors, warnings = [], []
     if os.path.isfile(test_ntuple_path):
-        if ".root" in test_ntuple_path.lower():
-            errors, warnings = do_options_parsing(
-                env_cmd,
-                out_dir,
-                join(out_dir, "output.pkl"),
-                test_ntuple_path,
-                job_name,
-                prod_data,
-            )
+        # TODO: This hasn't been updated to work with lb-prod-run
+        click.secho("Options parsing is currently unavailable", fg="yellow")
+        # if ".root" in test_ntuple_path.lower():
+        #     errors, warnings = do_options_parsing(
+        #         # TODO
+        #         env_cmd,
+        #         out_dir,
+        #         join(out_dir, "output.pkl"),
+        #         test_ntuple_path,
+        #         job_name,
+        #         prod_data,
+        #     )
+    elif any(
+        str(test_ntuple_path).lower() == join(out_dir, name).lower()
+        for name in out_dir.iterdir()
+    ):
+        warnings = [
+            "The output file has a different capitalisation to what is expected!"
+            " If this is a stripping job it could be due to a custom_stream"
+            " name not being written in all capital letters."
+        ]
     else:
-        if any(
-            test_ntuple_path.lower() == join(out_dir, name).lower()
-            for name in os.listdir(out_dir)
-        ):
-            warnings = [
-                "The output file has a different capitalisation to what is expected!"
-                " If this is a stripping job it could be due to a custom_stream"
-                " name not being written in all capital letters."
-            ]
-        else:
-            raise click.ClickException(
-                "ERROR: The expected output file does not exist!"
-            )
+        raise click.ClickException(
+            "ERROR: The expected output file does not exist!\n"
+            f"Expected: {test_ntuple_path}"
+        )
 
     warnings.extend(yaml_warnings)
-    if warnings:
-        for warning in warnings:
-            click.secho(f"WARNING: {warning}", fg="yellow")
+    for warning in warnings:
+        click.secho(f"WARNING: {warning}", fg="yellow")
 
     if errors:
         raise click.ClickException(
@@ -311,9 +308,11 @@ def test(production_name, job_name, dependent_input):
 @click.argument("job_name", type=str, nargs=1)
 @click.argument("test_ntuple_path", type=click.Path(exists=True), nargs=1)
 @click.argument("checks_output_dir", type=click.Path(), default="", nargs=1)
-def check(production_name, job_name, test_ntuple_path, checks_output_dir):
+@click.option("--validate/--no-validate", default=True)
+def check(production_name, job_name, test_ntuple_path, checks_output_dir, validate):
     """Run checks for a production"""
-    validate_environment()
+    if validate:
+        validate_environment()
     inside_ap_datapkg()
 
     # Obtain the right output file name
@@ -343,6 +342,7 @@ def check(production_name, job_name, test_ntuple_path, checks_output_dir):
 @main.command()
 @click.argument("production_name", type=production_name_type, nargs=1)
 @click.argument("job_name", type=str, nargs=1)
+@click.option("--validate/--no-validate", default=True)
 @click.option(
     "-i",
     "--dependent-input",
@@ -350,9 +350,10 @@ def check(production_name, job_name, test_ntuple_path, checks_output_dir):
     nargs=1,
     help="Run the test on a specific input file by passing either an LFN or a path to a local file",
 )
-def debug(production_name, job_name, dependent_input):
+def debug(production_name, job_name, dependent_input, validate):
     """Start an interactive session inside the job's environment"""
-    validate_environment()
+    if validate:
+        validate_environment()
     inside_ap_datapkg()
 
     enter_debugging(*prepare_test(production_name, job_name, dependent_input))
@@ -363,9 +364,11 @@ def debug(production_name, job_name, dependent_input):
 @click.argument("production_name", type=production_name_type, nargs=1)
 @click.argument("job_name", type=str, nargs=1)
 @click.argument("test_id", type=str, nargs=1, default="latest")
-def reproduce(pipeline_id, production_name, job_name, test_id):
+@click.option("--validate/--no-validate", default=True)
+def reproduce(pipeline_id, production_name, job_name, test_id, validate):
     """Reproduce an existing online test locally"""
-    validate_environment()
+    if validate:
+        validate_environment()
     enter_debugging(*prepare_reproduce(pipeline_id, production_name, job_name, test_id))
 
 
