@@ -10,9 +10,11 @@
 ###############################################################################
 import glob
 import os
+import pathlib
 import subprocess
 import tempfile
 from concurrent.futures import ThreadPoolExecutor
+from datetime import datetime
 from os.path import dirname, join
 
 import click
@@ -98,28 +100,27 @@ def check_production(production_name):
 
 def create_output_dir(production_name, require_cmt):
     """Create the directory structure for testing locally"""
-
-    from datetime import datetime
-
     date_string = datetime.now().strftime("%Y-%m-%d-%H-%M-%S")
-    testing_dir = join(os.getcwd(), "local-tests", f"{production_name}-{date_string}")
+    testing_dir = (
+        pathlib.Path.cwd() / "local-tests" / f"{production_name}-{date_string}"
+    )
     click.secho(f"Running tests in {testing_dir}", fg="green")
-    os.makedirs(testing_dir)
+    testing_dir.mkdir(parents=True)
 
-    dynamic_dir = join(testing_dir, "dynamic")
-    os.makedirs(dynamic_dir)
-    out_dir = join(testing_dir, "output")
-    os.makedirs(out_dir)
+    dynamic_dir = testing_dir / "dynamic"
+    dynamic_dir.mkdir(parents=True)
+    out_dir = testing_dir / "output"
+    out_dir.mkdir(parents=True)
 
-    main_dynamic_dir = join(os.getcwd(), "dynamic")
-    if os.path.exists(main_dynamic_dir):
+    main_dynamic_dir = pathlib.Path.cwd() / "dynamic"
+    if main_dynamic_dir.exists():
         click.secho(
             f"Found existing dynamic dir pointing to "
-            f"{os.readlink(main_dynamic_dir)}, unlinking",
+            f"{main_dynamic_dir.resolve()}, unlinking",
             fg="green",
         )
-        os.unlink(main_dynamic_dir)
-    os.symlink(dynamic_dir, main_dynamic_dir)
+        main_dynamic_dir.unlink()
+    main_dynamic_dir.symlink_to(dynamic_dir)
     write_jsroot_compression_options(dynamic_dir)
 
     # Create the fake install directory for lb-run
@@ -134,11 +135,7 @@ def log_popen_pipe(p, pipe_name):
     while p.poll() is None:
         line = getattr(p, pipe_name).readline()
         result += line
-        try:
-            line = line.decode().strip()
-        except UnicodeDecodeError:
-            line = repr(line)
-        click.echo(line)
+        click.echo(line.decode(errors="backslashreplace").rstrip("\n"))
     return result
 
 
@@ -158,26 +155,34 @@ def production_name_type(production_name):
     return production_name.strip("/")
 
 
-def recursively_create_input(production_name, dependent_job, desired_job):
+def recursively_create_input(production_name, job_name, prod_data):
     click.secho(
-        f"Running {dependent_job['job_name']} to provide the necessary input to {desired_job}",
+        f"Running {job_name} to provide the necessary input",
         fg="green",
     )
 
+    output_filetypes = prod_data[job_name]["output"]
+    if len(output_filetypes) != 1:
+        raise NotImplementedError(
+            "Testing jobs that take input from jobs with multiple outputs is not yet supported"
+        )
+
     # Run the job the desired job depends on
     result = logging_subprocess_run(
-        f"lb-ap test {production_name} {dependent_job['job_name']}", shell=True
+        f"lb-ap test {production_name} {job_name}", shell=True
     ).stdout.decode()
     # Get the output directory
     output_dir = result.split("\n")[-2].split(" ")[-1]
-    # if this is False clearly some other error has occured so don't bother continuing
+    # if this is False clearly some other error has occurred so don't bother continuing
     if os.path.exists(output_dir):
-        # Set the dependent input to lower case to handle inconsistencies between yaml definition and produced file
+        # Set the dependent input to lower case to handle inconsistencies between
+        # yaml definition and produced file
         dependent_input = (
-            output_dir + f"/00012345_00006789_1.{dependent_job['output'][0]}"
+            output_dir + f"/00012345_00006789_1.{output_filetypes[0]}"
         ).lower()
 
-        # set up a dictionary to map lower case output file names to their actual file name locations
+        # Set up a dictionary to map lower case output file names to their
+        # actual file name locations
         output_files_dict = {
             join(output_dir, name).lower(): join(output_dir, name)
             for name in os.listdir(output_dir)
@@ -186,12 +191,45 @@ def recursively_create_input(production_name, dependent_job, desired_job):
         # Check we have the desired output
         if dependent_input not in output_files_dict:
             raise OSError(
-                f"{dependent_job['job_name']} did not produce the desired output {dependent_input}"
+                f"{job_name} did not produce the desired output {dependent_input}"
             )
 
         return output_files_dict[dependent_input]
     else:
         raise OSError(
-            f"The expected output directory {output_dir} does not exist! It is likely that the test failed in some"
-            " way so the line in stdout upon test success that should provide the output location was not printed."
+            f"The expected output directory {output_dir} does not exist! "
+            "It is likely that the test failed in some way so the line in "
+            "stdout upon test success that should provide the output location "
+            "was not printed."
         )
+
+
+def resolve_input_overrides(prod_data, job_name):
+    override_input = None
+    output_filetype = None
+    if dependent_job := prod_data[job_name]["input"].get("job_name"):
+        job_data = prod_data[dependent_job]
+
+        if "bk_query" in job_data["input"]:
+            override_input = job_data["input"]
+            output_filetype = job_data["output"][0]
+        elif "transform_ids" in job_data["input"]:
+            override_input = job_data["input"]
+            output_filetype = job_data["output"][0]
+        elif "job_name" in job_data["input"]:
+            override_input, output_filetype = resolve_input_overrides(
+                prod_data, job_data["input"]["job_name"]
+            )
+        else:
+            raise NotImplementedError(
+                "Input requires either a bookkeeping location or a previous job name"
+            )
+    return override_input, output_filetype
+
+
+def check_status_code(response):
+    if not response.ok:
+        click.secho(response.url)
+        click.secho(response.text, fg="red")
+        raise click.ClickException("Network request failed")
+    return response
