@@ -12,6 +12,7 @@ import os
 import shutil
 import subprocess
 from os.path import dirname, join
+from pathlib import Path
 
 import pytest
 import requests
@@ -77,24 +78,41 @@ def without_proxy(mocker):
 def with_data(mocker):
     from subprocess import run as original_run
 
-    data_url = "http://s3.cern.ch/lhcb-analysis-productions-dev/test-data/00092443_00007924_7.AllStreams.dst"
-    data_fn = join(dirname(__file__), "data", "00092443_00007924_7.AllStreams.dst")
-    if not os.path.isfile(data_fn):
-        with requests.get(data_url, stream=True) as r:
-            with open(data_fn, "wb") as f:
-                shutil.copyfileobj(r.raw, f)
+    data_fn1 = Path(__file__).parent / "data" / "00070793_00000368_7.AllStreams.dst"
+    if not data_fn1.is_file():
+        url = (
+            f"http://s3.cern.ch/lhcb-analysis-productions-dev/test-data/{data_fn1.name}"
+        )
+        with requests.get(url, stream=True) as r, open(data_fn1, "wb") as f:
+            shutil.copyfileobj(r.raw, f)
+
+    data_fn2 = Path(__file__).parent / "data" / "00070767_00000368_7.AllStreams.dst"
+    if not data_fn2.is_file():
+        url = (
+            f"http://s3.cern.ch/lhcb-analysis-productions-dev/test-data/{data_fn2.name}"
+        )
+        with requests.get(url, stream=True) as r, open(data_fn2, "wb") as f:
+            shutil.copyfileobj(r.raw, f)
 
     pool_catalog_xml = (
         '<?xml version="1.0" encoding="UTF-8" standalone="no" ?>\n'
         "<!-- Edited By PoolXMLCatalog.py -->\n"
         '<!DOCTYPE POOLFILECATALOG SYSTEM "InMemory">\n'
         "<POOLFILECATALOG>\n"
-        '<File ID="6C5459F5-00AF-E911-9E41-0CC47A202CB8">\n'
+        '<File ID="980B119E-9609-E811-A58E-02163E016452">\n'
         "<physical>\n"
-        f'    <pfn filetype="ROOT_All" name="{data_fn}" se="CI-DST"/>\n'
+        f'    <pfn filetype="ROOT_All" name="{data_fn1}" se="CI-DST"/>\n'
         "</physical>\n"
         "<logical>\n"
-        '    <lfn name="/lhcb/MC/2018/ALLSTREAMS.DST/00092443/0000/00092443_00007924_7.AllStreams.dst"/>\n'
+        '    <lfn name="/lhcb/MC/2016/ALLSTREAMS.DST/00070793/0000/00070793_00000368_7.AllStreams.dst"/>\n'
+        "</logical>\n"
+        "</File>\n"
+        '<File ID="043C600A-8F09-E811-B65B-FA163E9FB5C5">\n'
+        "<physical>\n"
+        f'    <pfn filetype="ROOT_All" name="{data_fn2}" se="CI-DST"/>\n'
+        "</physical>\n"
+        "<logical>\n"
+        '    <lfn name="/lhcb/MC/2016/ALLSTREAMS.DST/00070767/0000/00070767_00000368_7.AllStreams.dst"/>\n'
         "</logical>\n"
         "</File>\n"
         "</POOLFILECATALOG>\n"
@@ -111,3 +129,11 @@ def with_data(mocker):
     mocker.patch("subprocess.run", new=my_run)
 
     yield pool_catalog_xml
+
+
+@pytest.fixture(scope="module")
+def vcr_config():
+    return {
+        "filter_headers": ["authorization", "set-cookie"],
+        "ignore_hosts": ["auth.cern.ch", "s3.cern.ch"],
+    }
